==> ci-hotel_V1.0.2_20101221.zip: ci-hotel_V1.0.2_20101221/system/application/views/admin/login/index.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>ci-hotel Administration</title>
<style type="text/css">
html, body {
	margin: 0;
	padding: 0;
}

#box {
	position:absolute;
	top:20%;
	left:20%;
	width:400px;
	background:#F6F6F6;
	color:black;
	text-align:center;
	border: #999 1px solid;
}

#header {
    color: #fff;
    background-color: #66f;
    height: 28px;
    font-size: 20px;
    font-weight: bold;
}

#footer {
    font-size: 14px;
    color: #fff;
    background-color: #66f;
    height: 20px;
}

h1 { font-size: 20px; }

/* input table */
table.inp {
	width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
}

table.inp th {
    padding: 2px;
    background: #F5F5F5;
    font-weight: bold;
    line-height: 120%;
    text-align: right;
}
table.inp td {
    padding: 2px;
    border-width: 0 0 1px 1px;
}

.error {
	color: #ff0000;
	font-size: 90%;
	font-style: italic;
}

.form_error {
	color: #ff0000;
	font-size: 90%;
	font-style: italic;
}

.form_error ul { list-style-type: none; }
</style>
</head>
<body>
<a href="<?php echo base_url() ?>">Front Page</a><br />

<div id="box">
<div id="header">ci-hotel 管理者ログイン</div>
<div id="content">

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err) 
    {
        echo '<li>' . $err . "</li>" . "\n"; 
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('admin/login/index/'); ?>
<br />
<table class="inp">
<tr><th>メールアドレス :</th><td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" />
<?php echo form_error('email'); ?>
</td></tr>
<th>パスワード :</th><td>
<input type="password" name="password" value="<?php echo set_value('password', isset($password) ? $password : ''); ?>" size="40" />
<?php echo form_error('password'); ?>
</td></tr></table>
<input type="submit" name="submit" value="ログイン" />
</form>
<br />
</div><!-- /content -->
<div id="footer">Copyright &copy; 2010 ci-hotel Project</div>
</div><!-- loginbox -->
</body>
</html>

==> ci-hotel_V1.2.1_20110211.zip: ci-hotel_V1.2.1_20110211/system/application/views/admin/login/index.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>ci-hotel Administration</title>
<style type="text/css">
html, body {
	margin: 0;
	padding: 0;
}

#box {
	position:absolute;
	top:20%;
	left:20%;
	width:400px;
	background:#F6F6F6;
	color:black;
	text-align:center;
	border: #999 1px solid;
}

#header {
    color: #fff;
    background-color: blue;
    height: 28px;
    font-size: 20px;
    font-weight: bold;
}

#footer {
    font-size: 14px;
    color: #fff;
    background-color: blue;
    height: 20px;
}

h1 { font-size: 20px; }

/* input table */
table.inp {
	width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
}

table.inp th {
    padding: 2px;
    background: #F5F5F5;
    font-weight: bold;
    line-height: 120%;
    text-align: right;
}
table.inp td {
    padding: 2px;
    border-width: 0 0 1px 1px;
}

.error {
	color: #ff0000;
	font-size: 90%;
	font-style: italic;
}

.form_error {
	color: #ff0000;
	font-size: 90%;
	font-style: italic;
}

.form_error ul { list-style-type: none; }
</style>
</head>
<body>
<a href="<?php echo base_url() ?>">Front Page</a><br />

<div id="box">
<div id="header">ci-hotel ホテル管理者ログイン</div>
<div id="content">

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err) 
    {
        echo '<li>' . $err . "</li>" . "\n"; 
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('admin/login/index/'); ?>
<br />
<table class="inp">
<tr><th>ユーザ名 :</th><td>
<input type="text" name="username" value="<?php echo set_value('username', isset($username) ? $username : ''); ?>" size="40" />
<?php echo form_error('username'); ?>
</td></tr>
<th>パスワード :</th><td>
<input type="password" name="password" value="<?php echo set_value('password', isset($password) ? $password : ''); ?>" size="40" />
<?php echo form_error('password'); ?>
</td></tr></table>
<input type="submit" name="submit" value="ログイン" />
</form>
<br />
</div><!-- /content -->
<div id="footer">Copyright &copy; 2010 ci-hotel Project</div>
</div><!-- loginbox -->
</body>
</html>
